/**
 * Projeto: JavaLight
 * Tipo:Cliente
 * @author Gustavo Santana(gals@cin.ufpe.br)
*/




package Cliente;
import Alimento.CadastroAlimentos;
import Alimento.RepositorioAlimentosLista;
import Exercicio.CadastroExercicios;
import Exercicio.RepositorioExerciciosLista;
import Semana.CadastroSemanas;
import Semana.RepositorioSemanaArray;


import Domestica.CadastroDomesticas;
import Domestica.RepositorioDomesticasLista;


public class Cliente {
    private String nome;
    private boolean logado;
    private String sexo; // M  mulher e H  homem
    private int peso, altura,idade; //idade em anos, peso em kg , altura em cm
    private CadastroExercicios serie;
    private CadastroSemanas dieta;
    private CadastroDomesticas tiposAtividade;



   /**
   * Construtor da classe Cliente
   *
   */
   public Cliente(String nome, int peso, String sexo , int altura, int idade) {
    this.nome = nome;
    this.sexo = sexo;
    this.peso = peso;
    this.altura = altura;
    this.idade = idade;
    logado = false;
    serie  = new CadastroExercicios(new RepositorioExerciciosLista());
    dieta  = new CadastroSemanas (new RepositorioSemanaArray()) ;
   }

   /**
    * seta o status de logado do cliente
    *
    * @param logadoTemp: Um booleano contendo o status do login do cliente
    *
    */
   public void setLogado (boolean logadoTemp) {
      logado = logadoTemp;
   }


   /**
    * seta o peso do cliente
    *
    * @param pesoTemp: Um inteiro contendo peso do cliente
    *
    */
   public void setPeso (int pesoTemp) {
      peso = pesoTemp;
   }

   /**
    * seta o nome do cliente
    *
    * @param nomeTemp: Uma string contendo o nome do cliente
    *
    */
   public void setNome (String nomeTemp) {
      this.nome = nomeTemp;
   }

   /**
    * seta o nome do cliente
    *
    * @param alturaTemp: Um inteiro contendo s altura do cliente
    *
    */
   public void setAltura (int alturaTemp){
      altura = alturaTemp;
   }

   /**
    * seta o sexo do cliente
    *
    * @param sexoTemp: Um boolean contendo o sexo do cliente
    *
    */
   public void setSexo (String sexoTemp){
      sexo = sexoTemp;
   }


   /**
    * seta a idade do cliente
    *
    * @param idadeTemp: Um inteiro contendo a idade do cliente
    *
    */
   public void setIdade (int idadeTemp){
      idade = idadeTemp;
   }

   /**
    * cria a srie de exerccios semanais do cliente
    *
    * @param serieTemp: Um objeto tipo CadastroExercicios
    *
    */
   public void setSerie ( CadastroExercicios serieTemp) {
      serie = serieTemp;
   }

   /**
    * cria a dieta do cliente
    *
    * @param dietaTemp: um objeto tipo CadastroSemanas
    *
    */
   public void setDieta ( CadastroSemanas dietatemp) {
      dieta = dietatemp;
   }

  /**
    * Retorna o peso do cliente
    *
    * @return: Um inteiro contendo o peso do cliente
    *
    */
   public int getPeso (){
      return peso;
   }

   /**
    * Retorna o status do login do cliente
    *
    * @return: Um boolena contendo o status de login do cliente
    *
    */
   public boolean getLogado (){
      return logado;
   }

   /**
    * Retorna o nome do cliente
    *
    * @return: Um string contendo o nome do cliente
    *
    */
   public String getNome (){
      return this.nome;
   }

   /**
    * Retorna a altura do cliente
    *
    * @return: Um inteiro contendo a altura do cliente
    *
    */
   public int getAltura (){
      return altura;
   }


   /**
    * Retorna o sexo do cliente
    *
    * @return: Um boolean contendo o sexo do cliente
    *
    */
   public String getSexo(){
      return sexo;
   }

   /**
    * Retorna o peso do cliente
    *
    * @return: Um inteiro contendo o peso do cliente
    *
    */
   public CadastroExercicios getSerie(){
      return serie;
   }


   /**
    * Retorna a dieta do cliente
    *
    * @return: Um objeto do tipo dieta
    *
    */
   public CadastroSemanas getDieta(){
      return this.dieta;
   }

 /**
    * Retorna a dieta do cliente
    *
    * @return: Um objeto do tipo dieta
    *
    */
   public CadastroDomesticas getTiposAtividade(){
      return this.tiposAtividade;
   }

   /**
    * Retorna a idade do cliente
    *
    * @return: Um inteiro contendo a idade do cliente
    *
    */
   public int getIdade (){
      return idade;
   }


  /**
    * Retorna o IMC (ndice de massa corprea) do cliente
    *
    * return: Uma string contendo o ndice de massa corprea do cliente
    *
    */
   public float IMC () {
      float a;
      a=(altura/(peso*peso));
      return a;
   }



   /**
    * Retorna o gasto metablico do cliente
    *
    * @return: Um double contendo o gasto metablico do cliente
    *
    */
   public double gastobasal() {

      double gasto=0;

      if(idade <= 12){
        gasto= (22.1 + (31.1*peso ) + (1.2 * altura));
      } else {
          if(sexo == "m"){ // 0   mulher
            gasto= (655 + (9.6*peso) + (1.8 * altura) - (4.7 * idade));
          }
          if(sexo == "h"){ // 1  homem
            gasto= (65 + (13.7 * peso) + (5 * altura) - (6.8 * idade));
         }
      }
      return gasto;
   }



}