/**
 * Projeto: JavaLight
 * Tipo: Alimento
 * @author Gustavo Santana(gals@cin.ufpe.br)
 */
package Semana;

import Alimento.Alimento;

public class CadastroSemanas {

    private RepositorioSemanas semanas;

  /**
   *
   * Construtor da classe CadastroSemanas
   *
   */
    public CadastroSemanas(RepositorioSemanas semanasTemp) {
        if ( semanasTemp == null ) {
            throw new IllegalArgumentException("Argumento invlido.");
        }
        else {
            semanas = semanasTemp;
        }
    }

   /**
    * Mtodo para mostrar a dieta
    *
    * @param dia: inteiro que indica o dia da dieta
    * @param semana: inteiro que indica a semana e o dia da dieta
    *
    */
    public void mostrarDieta (int dia , int semana) {
        semanas.getDiaDieta(dia,semana).mostrarTudo();
    }

   /**
    * Mtodo para escolher um alimento da lista
    *
    * @param nome: um String contendo o nome do exerccio
    * @param alimentoTemp: um booleano verificando se houve a remoo ou no
    *
    */
    public void escolher (Alimento alimentoTemp, int dia , int semana) {
        if( alimentoTemp == null) {
            throw new IllegalArgumentException("Argumento invlido.");
        } else {
            semanas.getDiaDieta(dia,semana).criarAlimento(alimentoTemp);
        }
    }

   /**
    * Mtodo para procurar um alimento na lista
    *
    * @param nome: um inteiro contendo o nome do alimento
    * @param dia: o dia que comeou o
    * @param semana: um inteiro contendo a semana atual
    * return: um objeto do tipo Alimento
    *
    */
    public Alimento procurarAlimento (String nome,int dia , int semana) {
        Alimento retorno =  null;

        if ( nome == null) {
            throw new IllegalArgumentException("Argumento invlido");
        }
        else {
            retorno = semanas.getDiaDieta(dia,semana).procurarAlimento(nome);
        }

        return retorno;
    }


   /**
    * Mtodo para verofocar se tal alimento existe na dieta
    *
    * @param nome: um String contendo o nome do exerccio
    * return: um booleano verificando se exisite ou no
    *
    */
    public boolean existeAlimentoNaDieta (String nome, int dia , int semana) {
        boolean retorno = false;

        if ( nome == null ) {
            throw new IllegalArgumentException("Argumento invlido");
        }
        else {
            retorno = semanas.getDiaDieta(dia,semana).existeAlimento(nome);
        }

        return retorno;
    }

   /**
    * Mtodo para adicionar um alimento na lista
    *
    * @param alimento: um objeto do tipo alimento
    * @param semana: um inteiro contendo o nmero da semana
    * @param dia: um inteiro contendo o nmero do dia
    *
    */
    public void adicionar (Alimento alimento, int semana, int dia) {
        if ( alimento == null ) {
            throw new IllegalArgumentException("Argumento invlido.");
        }
        else {
            semanas.adicionarAlimento(semana,dia,alimento);
        }
    }

   /**
    * Mtodo para retornar as semanas
    *
    */
    public RepositorioSemanas getSemanas() {
        return this.semanas;
    }
}