/**
 * Projeto: JavaLight
 * Tipo:Cliente
 * @author Gustavo Santana(gals@cin.ufpe.br)
 */
package Semana;


import Alimento.*;
public class Semana {

    private int noPontos;
    private CadastroAlimentos[] semana;

   /**
    * Construtor da classe Semana
    *
    * @param pontos: Inteiro contendo a quantidade de pontos permitido por semana
    *
    */
    public Semana (int pontos) {
        this.semana = new CadastroAlimentos[7];
        this.noPontos = pontos;
    }

   /**
    * Mtodo getNopontos
    *
    * return: inteiro contendo o nmero de pontos que restam na semana
    *
    */
    public int getNoPontos() {
        return this.noPontos;
    }

    public void bonus ( int qtBonus ) {
        this.noPontos = this.noPontos + qtBonus;
    }

   /**
    * Mtodo removerAlimento
    *
    * @param nome: string contendo o nome do alimento
    * @param dia: inteiro contendo o ndice do dia
    *
    */
    public boolean removerAlimento (String nome, int dia) throws AlimentoInexistenteException{
        boolean teste = false;

        if( nome == null ) {
            throw new IllegalArgumentException("Argumento invlido.");
        } else {
            if( semana[dia].existeAlimento(nome) ) {
               teste = semana[dia].removerAlimento(nome);
               this.noPontos = this.noPontos + semana[dia].procurarAlimento(nome).getPontos();
            } else {
//                throw new AlimentoNaoExistenteException();
            }
        }
        return teste;
    }

   /**
    * Mtodo existeAlimentoNoDia
    *
    * @param nome: string contendo o nome do alimento
    * @param dia: inteiro contendo o ndice do dia
    *
    * return: booleano contendo o valor verdade relativo  existncia do alimento
    */
    public boolean existeAlimentoNoDia (String nome, int dia) {
        boolean retorno = false;

        if( nome == null ) {
            throw new IllegalArgumentException("Argumento invlido.");
        } else {
            retorno = semana[dia].existeAlimento(nome);
        }
        return retorno;
    }

   /**
    * Mtodo existeAlimentoNoDia
    *
    * @param dia: inteiro contendo o ndice do dia
    *
    * return: objeto do tipo CadastroAlimentos
    */
    public CadastroAlimentos getDieta (int dia) {
        CadastroAlimentos retorno = null;

        if (dia < 7 && dia >= 0) {
         // semana[dia] = new CadastroAlimento();
            retorno = this.semana[dia];
        }

        return retorno;
    }

    /**
    * Mtodo adicionar
    *
    * @param dia: inteiro contendo o ndice do dia
    * @param alimento: objeto do tipo Alimento
    *
    */
    public void adicionar (Alimento alimento,int dia) throws AlimentoExistenteException{
        CadastroAlimentos temp;

        if( alimento == null ) {
            throw new IllegalArgumentException("Argumento invlido.");
        } else {
            if ( (dia < 7) && (dia >0) && ( alimento.getPontos() <= 10 ) &&
                    ( alimento.getPontos() >=0 ) ) {

                if(semana[dia] == null) {
                    semana[dia] = new CadastroAlimentos(new RepositorioAlimentosLista());
                }

                this.noPontos = this.noPontos - alimento.getPontos();
                semana[dia].criarAlimento(alimento);
            }
        }
    }
}
